==> pegasus-2.7.0.tar.gz: pegasus/src/Executor/Globals.h <==
/*
//%2006////////////////////////////////////////////////////////////////////////
//
// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
// IBM Corp.; EMC Corporation, The Open Group.
// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
// EMC Corporation; VERITAS Software Corporation; The Open Group.
// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
// EMC Corporation; Symantec Corporation; The Open Group.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
//%/////////////////////////////////////////////////////////////////////////////
*/

#ifndef _Executor_Globals_h
#define _Executor_Globals_h

#include "Defines.h"

/*
**==============================================================================
**
** struct Globals
**
**     This structure contains all globally visible data.
**
**==============================================================================
*/

struct Globals
{
    /* Same as argc passed to main(). */
    int argc;

    /* Same as argv passed to main(). */
    char** argv;

    /* PID of child process (CIMSERVERMAIN). */
    int childPid;

    /* Indicates whether we are in the Child process.  If true, we need to
     * call _exit() instead of exit().
     */
    int isChildProcess;

    /* Mask of signals encountered by executor process. */
    unsigned long signalMask;

    /* Same as the Pegasus enableAuthentication configuration option, either
     * passed to the command line or found in the planned configuration file.
     */
    int enableAuthentication;
};

EXECUTOR_LINKAGE
extern struct Globals globals;

#endif /* _Executor_Globals_h */

==> pegasus-2.7.2.tar.gz: pegasus/src/Executor/Globals.h <==
/*
//%2006////////////////////////////////////////////////////////////////////////
//
// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
// IBM Corp.; EMC Corporation, The Open Group.
// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
// EMC Corporation; VERITAS Software Corporation; The Open Group.
// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
// EMC Corporation; Symantec Corporation; The Open Group.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
//%/////////////////////////////////////////////////////////////////////////////
*/

#ifndef _Executor_Globals_h
#define _Executor_Globals_h

#include "Defines.h"

/*
**==============================================================================
**
** struct Globals
**
**     This structure contains all globally visible data.
**
**==============================================================================
*/

struct Globals
{
    /* Same as argc passed to main(). */
    int argc;

    /* Same as argv passed to main(). */
    char** argv;

    /* A pipe to alert the cimserver command when the server is initialized. */
    int initCompletePipe;

    /* PID of child process (CIMSERVERMAIN). */
    int childPid;

    /* Indicates whether we are in the Child process.  If true, we need to
     * call _exit() instead of exit().
     */
    int isChildProcess;

    /* Mask of signals encountered by executor process. */
    unsigned long signalMask;

    /* Same as the Pegasus enableAuthentication configuration option, either
     * passed to the command line or found in the planned configuration file.
     */
    int enableAuthentication;

    /* Indicates whether terminal I/O streams should be left intact. */
    int bindVerbose;
};

EXECUTOR_LINKAGE
extern struct Globals globals;

#endif /* _Executor_Globals_h */
